# Agenteasy
<a href="https://pypi.org/project/agenteasy/">
    <img src="https://img.shields.io/pypi/v/agenteasy"
         alt="PyPI package version">
  </a>
<a href="https://dermartinli.github.io/agenteasy">
    <img src="https://img.shields.io/badge/-documentation-blue"
         alt="Documentation">
</a>
<a href="https://www.python.org">
    <img src="https://img.shields.io/pypi/pyversions/agenteasy"
         alt="Python versions">
</a>
<a href="https://github.com/derMartinLi/agenteasy/blob/main/LICENSE">
    <img src="https://img.shields.io/github/license/derMartinLi/agenteasy"
         alt="GitHub license">
  </a>
</p>

---
